/* Copyright  2007 by Christian Fuchsberger and Lukas Forer info@pedvizapi.org.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License <http://www.pedvizapi.org/gpl.txt>
 * for more details. 
 */

package applets.abstr3d;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GridLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;

import javax.swing.JApplet;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import pedviz.algorithms.HierarchieUpDown;
import pedviz.algorithms.*;
import pedviz.algorithms.SameParents;
import pedviz.algorithms.sugiyama.*;
import pedviz.graph.Graph;
import pedviz.graph.Hierarchy;
import pedviz.graph.LayoutedGraph;
import pedviz.graph.Node;
import pedviz.loader.RessourceGraphLoader;
import pedviz.view.DefaultEdgeView;
import pedviz.view.DefaultNodeView;
import pedviz.view.*;
import pedviz.view.GraphView2D;
import pedviz.view.rules.*;
import pedviz.view.rules.ColorRule;
import pedviz.view.rules.ShapeRule;
import pedviz.view.symbols3d.*;

public class Abstr extends JApplet {
	private GraphView graphView;

	private Graph graph;

	private AbstractionRule3d abstr;

	private String[] data = { "no caption", "total", "male | female" };

	public void init() {

		graph = new Graph();

		String file = getParameter("datasource");
		RessourceGraphLoader loader = new RessourceGraphLoader(file, ",");
		loader.setSettings("PID", "MOM", "DAD");
		loader.load(graph);

		DefaultNodeView d = new DefaultNodeView();
		d.setColor(new Color(255, 255, 255));
		d.addHintAttribute("pid");
		d.addHintAttribute("sex");
		d.addHintAttribute("flag");

		SameParents sameParents = new SameParents(graph);
		sameParents.run();

		graph.buildHierarchie(new HierarchieUpDown());

		// runs sugiyama
		SugiyamaLayout l = new SugiyamaLayout(graph, d, new DefaultEdgeView());
		l.setSplitter(new RandomSplitter());
		l.run();

		// Add flag
		for (Node node : graph.getAllNodes()) {
			if (node.getLevel() < 2) {
				l.getLayoutGraph().getNodeView(node).setExpand(false);
			}
		}

		// RubberBands2 ingores nodes with flag="1"
		RubberBands rubberBands = new RubberBands(l.getLayoutGraph());
		rubberBands.run();

		// for 2d:
		graphView = new GraphView3D(l.getLayoutGraph());
		graphView.setBackgroundColor(new Color(255, 255, 255));

		// color rules
		ColorRule colorRule = new ColorRule("adopted", "1", Color.red);
		colorRule.addRule("fam", "1", Color.cyan);
		colorRule.addRule("sex", "1", Color.yellow);
		colorRule.addRule("dead", "1", Color.green);
		graphView.addRule(colorRule);

		// symbols
		graphView.addRule(new ShapeRule("sex", "2", new SymbolSexMale3d()));
		graphView.addRule(new ShapeRule("sex", "1", new SymbolSexFemale3d()));
		// draws abstract nodes
		abstr = new AbstractionRule3d();
		graphView.addRule(abstr);

		getContentPane().add(graphView.getComponent());
	}

}
