/* Copyright  2007 by Christian Fuchsberger and Lukas Forer info@pedvizapi.org.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License <http://www.pedvizapi.org/gpl.txt>
 * for more details. 
 */

package applets.highlighting;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GridLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;
import java.util.HashMap;

import javax.swing.JApplet;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import pedviz.algorithms.Highlighter;
import pedviz.algorithms.Sugiyama;
import pedviz.graph.Graph;
import pedviz.graph.LayoutedGraph;
import pedviz.graph.Node;
import pedviz.loader.RessourceGraphLoader;
import pedviz.view.*;
import pedviz.view.rules.ShapeRule;
import pedviz.view.symbols.SymbolSexFemale;
import pedviz.view.symbols.SymbolSexMale;

public class LinesOfDescents extends JApplet {
	private GraphView graphView;

	private int mode = Highlighter.SUCCESSORS;

	private Graph graph;

	private HashMap<String, Integer> data;

	public void init() {

		data = new HashMap<String, Integer>();
		data.put("maternal", Highlighter.MATERNAL);
		data.put("paternal", Highlighter.PATERNAL);
		data.put("maternal and paternal", Highlighter.MATERNAL_AND_PATERNAL);
		data.put("all ancestors", Highlighter.ANCESTORS);
		data.put("all successors", Highlighter.SUCCESSORS);
		data.put("all ancestors and successors",
				Highlighter.SUCCESSORS_AND_ANCESTORS);

		graph = new Graph();

		RessourceGraphLoader loader = new RessourceGraphLoader(
				getParameter("datasource"), ",");

		loader.setSettings("PID", "MOM", "DAD");
		loader.load(graph);

		DefaultNodeView n = new DefaultNodeView();
		n.setColor(new Color(255, 255, 255));
		n.setHighlightedColor(Color.red);
		n.addHintAttribute("pid");
		n.addHintAttribute("mom");
		n.addHintAttribute("dad");

		DefaultEdgeView e = new DefaultEdgeView();
		e.setHighlightedColor(Color.red);

		Sugiyama sugiyama = new Sugiyama(graph, n, e);
		sugiyama.run();

		LayoutedGraph lgraph = sugiyama.getLayoutedGraph();
		graphView = new GraphView2D();
		graphView.addRule(new ShapeRule("sex", "2", new SymbolSexFemale()));
		graphView.addRule(new ShapeRule("sex", "1", new SymbolSexMale()));

		graphView.setSelectionEnabled(true);
		final LODHighlighter lodHighlighter = new LODHighlighter(mode);
		graphView.addNodeListener(lodHighlighter);

		JPanel toolBar = new JPanel();
		toolBar.setLayout(new BorderLayout());
		toolBar.setBackground(Color.WHITE);
		JPanel toolBar2 = new JPanel();
		toolBar.add(toolBar2, BorderLayout.LINE_END);
		toolBar2.setLayout(new GridLayout(1, 2));
		toolBar2.setBackground(Color.WHITE);

		JComboBox dataList = new JComboBox(data.keySet().toArray());
		dataList.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				JComboBox item = (JComboBox) e.getSource();
				mode = data.get(item.getSelectedItem());
				lodHighlighter.setMode(mode);
			}
		});

		JLabel caption = new JLabel("Line of Descents: ");
		caption.setHorizontalAlignment(JLabel.RIGHT);
		toolBar2.add(caption, BorderLayout.LINE_END);
		toolBar2.add(dataList, BorderLayout.LINE_END);
		getContentPane().add(toolBar, BorderLayout.PAGE_END);
		getContentPane().add(graphView.getComponent());
		graphView.setGraph(lgraph);
	}
}
