package applets.magic;

import java.awt.*;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.util.ArrayList;

import javax.swing.*;

import pedviz.algorithms.*;
import pedviz.algorithms.magiceye.*;
import pedviz.graph.*;
import pedviz.loader.CsvGraphLoader;
import pedviz.loader.RessourceGraphLoader;
import pedviz.view.*;
import pedviz.view.rules.AbstractionRule3d;
import pedviz.view.rules.ShapeRule;
import pedviz.view.symbols3d.Symbol3D;
import pedviz.view.symbols3d.SymbolSexFemale3d;
import pedviz.view.symbols3d.SymbolSexMale3d;
import pedviz.view.symbols3d.SymbolSexUndesignated3d;

import com.sun.j3d.utils.universe.SimpleUniverse;

public class MagicEye extends JApplet {

	public void init() {
		setSize(800, 600);

		final Graph graph = new Graph();

		String file = "/family_1089.csv";
		RessourceGraphLoader loader = new RessourceGraphLoader(file, ",");
		// sets columnnames for id, mom-id and dad-id
		loader.setSettings("PID", "MOM", "DAD");
		loader.load(graph);

		// node look
		DefaultEdgeView e = new DefaultEdgeView();
		e.setWidth(0.0005f);
		e.setColor(new Color(150, 150, 150));
		e.setAlphaForLongLines(0.5f);
		e.setGapBottom(0);
		e.setGapTop(0);
		e.setDeltaForLongLines(30, 30, 30);
		e.setHighlightedColor(Color.red);

		DefaultNodeView n = new DefaultNodeView();
		n.setSize(0.8f);
		n.setColor(Color.orange);

		graph.buildHierarchie(new MagicHierarchieBuilder());

		MagicEyeLayout layout = new MagicEyeLayout(graph, n, e);
		layout.run();
		final GraphView3D graphView = new GraphView3D();

		graphView.addRule(new ShapeRule("SEX", "1", new SymbolSexFemale3d(
				Symbol3D.STYLE_TURM)));
		graphView.addRule(new ShapeRule("SEX", "2", new SymbolSexMale3d(
				Symbol3D.STYLE_TURM)));

		graphView.setTransparencyEnabled(true);
		graphView.setAntialiasingEnabled(true);
		graphView.addNodeListener(new LODHighlighter(
				LODHighlighter.SUCCESSORS_AND_ANCESTORS));

		graphView.setSelectionEnabled(true);
		graphView.setXRotatingEnabled(true);
		graphView.setGraph(layout.getLayoutGraph());
		getContentPane().add(graphView.getComponent());
	}
}
