/* Copyright  2007 by Christian Fuchsberger and Lukas Forer info@pedvizapi.org.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License <http://www.pedvizapi.org/gpl.txt>
 * for more details. 
 */

package applets.path;

// 3DPedViz imports
import java.awt.Color;
import java.util.ArrayList;

import javax.swing.JApplet;
import javax.swing.JOptionPane;

import pedviz.algorithms.Highlighter;
import pedviz.algorithms.Sugiyama;
import pedviz.graph.Graph;
import pedviz.graph.LayoutedGraph;
import pedviz.graph.Node;
import pedviz.loader.RessourceGraphLoader;
import pedviz.view.*;
import pedviz.view.rules.ShapeRule;
import pedviz.view.symbols.SymbolSexFemale;
import pedviz.view.symbols.SymbolSexMale;

public class Path extends JApplet {
	private GraphView graphView;

	private Graph graph;

	public void init() {

		graph = new Graph();

		RessourceGraphLoader loader = new RessourceGraphLoader(
				getParameter("datasource"), ",");

		// sets columnnames for id, mom-id and dad-id
		loader.setSettings("PID", "MOM", "DAD");
		loader.load(graph);

		DefaultNodeView n = new DefaultNodeView();
		DefaultEdgeView e = new DefaultEdgeView();

		e.setColor(new Color(100, 100, 100));
		e.setHighlightedColor(Color.red);
		e.setColorForLongLines(new Color(200, 200, 200));
		e.setConnectChildren(true);
		e.setGapBottom(5);

		n.addHintAttribute("pid");
		n.setColor(new Color(255, 255, 255));
		n.setMouseOverColor(new Color(255, 0, 0));

		// runs sugiyama
		Sugiyama sugiyama = new Sugiyama(graph, n, e);
		sugiyama.run();

		LayoutedGraph lgraph = sugiyama.getLayoutedGraph();
		graphView = new GraphView2D();
		graphView.setBackgroundColor(new Color(255, 255, 255));
		graphView.addRule(new ShapeRule("sex", "2", new SymbolSexFemale()));
		graphView.addRule(new ShapeRule("sex", "1", new SymbolSexMale()));
		graphView.setSelectionEnabled(true);
		graphView.setMultiselection(true);
		graphView.addNodeListener(new PathHighlighter());
		getContentPane().add(graphView.getComponent());
		graphView.setGraph(lgraph);
	}
}
