/* Copyright  2007 by Christian Fuchsberger and Lukas Forer info@pedvizapi.org.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License <http://www.pedvizapi.org/gpl.txt>
 * for more details. 
 */

package applets.symbols;

import java.awt.Color;

import javax.swing.JApplet;

import pedviz.algorithms.Sugiyama;
import pedviz.algorithms.sugiyama.SugiyamaNodeView;
import pedviz.graph.*;
import pedviz.loader.RessourceGraphLoader;
import pedviz.view.DefaultEdgeView;
import pedviz.view.DefaultNodeView;
import pedviz.view.GraphView;
import pedviz.view.*;
import pedviz.view.NodeView;
import pedviz.view.rules.ColorRule;
import pedviz.view.rules.HintRule;
import pedviz.view.rules.ShapeRule;
import pedviz.view.symbols.SymbolAdopted;
import pedviz.view.symbols.SymbolDeceased;
import pedviz.view.symbols.SymbolSexFemale;
import pedviz.view.symbols.SymbolSexMale;
import pedviz.view.symbols.SymbolSexUndesignated;

public class Symbols extends JApplet {
	static GraphView graphView;

	public void init() {

		setSize(800, 600);

		final Graph graph = new Graph();

		RessourceGraphLoader loader = new RessourceGraphLoader(
				getParameter("datasource"), ",");

		// sets columnnames for id, mom-id and dad-id
		loader.setSettings("PID", "MOM", "DAD");
		loader.load(graph);

		DefaultEdgeView e = new DefaultEdgeView();
		e.setColor(new Color(50, 50, 50));
		e.setColorForLongLines(new Color(200, 200, 200));
		e.setGapBottom(5);
		e.setConnectChildren(true);

		DefaultNodeView d = new DefaultNodeView();
		d.setColor(new Color(255, 255, 255));
		d.setBorderColor(new Color(0, 0, 0));
		d.addHintAttribute("pid");

		Sugiyama sugiyama = new Sugiyama(graph, d, e);
		sugiyama.run();

		LayoutedGraph lgraph = sugiyama.getLayoutedGraph();
		graphView = new GraphView2D();
		getContentPane().add(graphView.getComponent());

		graphView.setBackgroundColor(new Color(255, 255, 255));

		ColorRule colorRule = new ColorRule("adopted", "1", Color.red);
		colorRule.addRule("fam", "1", Color.cyan);
		colorRule.addRule("sex", "1", Color.yellow);
		colorRule.addRule("dead", "1", Color.green);
		graphView.addRule(colorRule);

		graphView.addRule(new ShapeRule("sex", "-1",
				new SymbolSexUndesignated()));
		graphView.addRule(new ShapeRule("sex", "1", new SymbolSexMale()));
		graphView.addRule(new ShapeRule("sex", "2", new SymbolSexFemale()));
		graphView.addRule(new ShapeRule("dead", "1", new SymbolDeceased()));
		graphView.addRule(new ShapeRule("adopted", "1", new SymbolAdopted()));

		graphView.addRule(new HintRule() {
			@Override
			public String getHint(NodeView n) {
				return n.getNode().getId() + "\n{line}\nsex: "
						+ n.getNode().getUserData("SEX") + "\ndad: "
						+ n.getNode().getIdDad() + "\nmom:"
						+ n.getNode().getIdMom();
			}
		});
		graphView.setGraph(lgraph);

	}
}
